@@ -21,7 +21,7 @@ loss.ncvreg <- function(y, yhat, family) {
   }
   val
 }
-loss.ncvsurv <- function(y, eta) {
+loss.ncvsurv <- function(y, eta, total=TRUE) {
   ind <- order(y[,1])
   d <- as.numeric(y[ind,2])
   if (is.matrix(eta)) {
@@ -31,5 +31,9 @@ loss.ncvsurv <- function(y, eta) {
     eta <- eta[ind]
     r <- rev(cumsum(rev(exp(eta))))
   }
-  -1*(crossprod(d, eta) - crossprod(d, log(r)))
+  if (total) {
+    return(-1*(crossprod(d, eta) - crossprod(d, log(r))))
+  } else {
+    return(-1*(eta[d==1,] - log(r)[d==1,]))
+  }
 }
