@@ -1,13 +1,11 @@
 ## ------------------------------------------------------------------------
-## Linear regression
-data(prostate)
-X <- as.matrix(prostate[,1:8])
-y <- prostate$lpsa
-head(X)
-head(y)
+# Linear regression
+data(Prostate)
+head(Prostate$X)
+head(Prostate$y)
 
 ## ------------------------------------------------------------------------
-fit <- ncvreg(X, y)
+fit <- ncvreg(Prostate$X, Prostate$y)
 
 ## ----opts.label='fig'----------------------------------------------------
 plot(fit)
@@ -16,13 +14,13 @@ plot(fit)
 coef(fit, lambda=0.1)
 
 ## ----opts.label='fig'----------------------------------------------------
-cvfit <- cv.ncvreg(X, y)
+cvfit <- cv.ncvreg(Prostate$X, Prostate$y)
 plot(cvfit)
 
 ## ------------------------------------------------------------------------
 coef(cvfit)
 
 ## ------------------------------------------------------------------------
-predict(cvfit, X=head(X))
+predict(cvfit, X=head(Prostate$X))
 predict(cvfit, type="nvars")
 
